@@ -6,7 +6,7 @@ legendBreaks = function(pos,
     rev=TRUE,
     outer=TRUE,
     pch=15,
-    bg=par('bg'),
+    bg='white',
     cex=par('cex'),
     pt.cex=2.5*cex,
     text.col=par('fg'),
